@@ -7,28 +7,26 @@ use POSIX                 qw/strftime modf/;
 use Carp                  qw/croak/;
 use feature 'state';
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 #======================================================================
 # ATTRIBUTES
 #======================================================================
 
 # PUBLIC ATTRIBUTES
-has 'xlsx'            => (is => 'ro', isa => 'Str', required => 1);      # path of xlsx file
+has 'xlsx'            => (is => 'ro', isa => 'Str|FileHandle', required => 1);      # path of xlsx file
 has 'using'           => (is => 'ro', isa => 'Str', default => 'Regex'); # name of backend class
 has 'date_format'     => (is => 'ro', isa => 'Str', default => '%d.%m.%Y');
 has 'time_format'     => (is => 'ro', isa => 'Str', default => '%H:%M:%S');
-has 'datetime_format' => (is => 'ro', isa => 'Str',
-                          builder => '_datetime_format', lazy => 1);
-has 'date_formatter'  => (is => 'ro',   isa => 'Maybe[CodeRef]',
-                          builder => '_date_formatter', lazy => 1);
+has 'datetime_format' => (is => 'ro', isa => 'Str',            builder => '_datetime_format', lazy => 1);
+has 'date_formatter'  => (is => 'ro', isa => 'Maybe[CodeRef]', builder => '_date_formatter', lazy => 1);
 
 
 
 # ATTRIBUTES USED INTERNALLY, NOT DOCUMENTED
 has 'backend'         => (is => 'ro',   isa => 'Object', init_arg => undef,
                           builder => '_backend', lazy => 1,
-                          handles => [qw/values base_year sheets/]);
+                          handles => [qw/values base_year sheets active_sheet/]);
 
 #======================================================================
 # BUILDING
@@ -39,12 +37,8 @@ around BUILDARGS => sub {
   my $orig  = shift;
   my $class = shift;
 
-  if ( @_ == 1 && !ref $_[0] ) {
-    return $class->$orig(xlsx => $_[0]);
-  }
-  else {
-    return $class->$orig(@_);
-  }
+  return ( @_ == 1 && !ref $_[0] ) ? $class->$orig(xlsx => $_[0])
+                                   : $class->$orig(@_);
 };
 
 
@@ -260,7 +254,7 @@ sub _subrange {
 
   # restrict to the column range
   my @col_nums = map {$self->A1_to_num($_) - 1} ($col1, $col2);
-  if ($col_nums[0] > 1){ # THINK : should check if $colnum2 is smaller that the max row size ??
+  if ($col_nums[0] > 1){
     my @col_range = ($col_nums[0] .. $col_nums[1]);
     $values = [map { [ @$_[@col_range] ]} @$values];
   }
@@ -281,11 +275,11 @@ Excel::ValueReader::XLSX - extracting values from Excel workbooks in XLSX format
 
 =head1 SYNOPSIS
 
-  my $reader = Excel::ValueReader::XLSX->new(xlsx => $filename);
+  my $reader = Excel::ValueReader::XLSX->new(xlsx => $filename_or_handle);
   # .. or with syntactic sugar :
-  my $reader = Excel::ValueReader::XLSX->new($filename);
+  my $reader = Excel::ValueReader::XLSX->new($filename_or_handle);
   # .. or with LibXML backend :
-  my $reader = Excel::ValueReader::XLSX->new(xlsx => $filename,
+  my $reader = Excel::ValueReader::XLSX->new(xlsx => $filename_or_handle,
                                              using => 'LibXML');
   
   foreach my $sheet_name ($reader->sheet_names) {
@@ -302,20 +296,26 @@ Excel::ValueReader::XLSX - extracting values from Excel workbooks in XLSX format
      print "table $table_name has $n_data_rows rows and $n_columns columns; ",
            "column 'foo' in first row contains : ", $rows->[0]{foo};
   }
+  
+  my $first_grid = $reader->values(1); # if using numerical indices, start at 1
 
 =head1 DESCRIPTION
 
+=head2 Purpose
+
 This module reads the contents of an Excel file in XLSX format.
 Unlike other modules like L<Spreadsheet::ParseXLSX> or L<Spreadsheet::XLSX>, 
 there is no support for reading formulas, formats or other Excel internal
 information; all you get are plain values -- but you get them much
 faster ! Besides, this module also has support for parsing Excel tables.
 
-This front module has two different backends for extracting values :
+=head2 Backends
+
+Two different backends may be used for extracting values :
 
 =over
 
-=item Regex (default)
+=item Regex
 
 this backend uses regular expressions to parse the XML content.
 
@@ -327,22 +327,33 @@ It is probably safer but about three times slower than the Regex backend
 
 =back
 
+The default is the C<Regex> backend.
+
+=head2 Sheet numbering
+
+Although worksheets are usually accessed by name, they may also
+be accessed by numerical indices, I<starting at value 1>.
+Some other Perl parsing modules use a different convention, where the first sheet has index 0.
+Here index 1 was chosen to be consistent with the common API for "collections" in
+Microsoft Office object model.
+
 
 =head1 METHODS
 
 =head2 new
 
-  my $reader = Excel::ValueReader::XLSX->new(xlsx  => $filename,
+  my $reader = Excel::ValueReader::XLSX->new(xlsx  => $filename_or_handle,
                                              using => $backend,
                                              %date_formatting_options);
 
-The C<xlsx> argument is mandatory and points to the C<.xlsx> file to be parsed.
+The C<xlsx> argument is mandatory and points to the C<.xlsx> file to be parsed,
+or is an open filehandle.
 The C<using> argument is optional; it specifies the backend to be used for parsing;
 default is 'Regex'.
 
 As syntactic sugar, a shorter form is admitted :
 
-  my $reader = Excel::ValueReader::XLSX->new($filename);
+  my $reader = Excel::ValueReader::XLSX->new($filename_or_handle);
 
 Optional parameters for formatting date and time values
 are described in the L</DATE AND TIME FORMATS> section below.
@@ -354,6 +365,13 @@ are described in the L</DATE AND TIME FORMATS> section below.
 
 Returns the list of worksheet names, in the same order as in the Excel file.
 
+=head2 active_sheet
+
+  my $active_sheet_number = $reader->active_sheet;
+
+Returns the numerical index (starting at 1) of the sheet that was active when the file was last saved.
+May return C<undef>.
+
 =head2 values
 
   my $grid = $reader->values($sheet);
@@ -619,7 +637,11 @@ signaled that the 'r' attribute in cells is optional.
 
 =item *
 
-Ulibuck signaled bugs several minor bugs on the LibXML backend
+Ulibuck signaled bugs several minor bugs on the LibXML backend.
+
+=item *
+
+H.Merijn Brand suggested additions to the API.
 
 =back
 
