@@ -4,8 +4,9 @@ use 5.10.1;
 use Moose;
 use Archive::Zip          qw(AZ_OK);
 use Carp                  qw/croak/;
+use Scalar::Util          qw/openhandle/;
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 #======================================================================
 # ATTRIBUTES
@@ -14,14 +15,13 @@ has 'frontend'      => (is => 'ro', isa => 'Excel::ValueReader::XLSX',
                         required => 1, weak_ref => 1,
                         handles => [qw/A1_to_num formatted_date/]);
 
-
-
 my %lazy_attrs = ( zip             => 'Archive::Zip',
                    date_styles     => 'ArrayRef',
                    strings         => 'ArrayRef',
                    workbook_data   => 'HashRef',
                    table_info      => 'HashRef',
-                   sheet_for_table => 'ArrayRef',  );
+                   sheet_for_table => 'ArrayRef',
+                  );
 
 while (my ($name, $type) = each %lazy_attrs) {
   has $name => (is => 'ro', isa => $type, builder => "_$name", init_arg => undef, lazy => 1);
@@ -37,10 +37,12 @@ while (my ($name, $type) = each %lazy_attrs) {
 sub _zip {
   my $self = shift;
 
-  my $xlsx_file = $self->frontend->xlsx;
-  my $zip       = Archive::Zip->new;
-  my $result    = $zip->read($xlsx_file);
-  $result == AZ_OK  or die "cannot unzip $xlsx_file";
+  my $zip                  = Archive::Zip->new;
+  my $xlsx_source          = $self->frontend->xlsx;
+  my ($meth, $source_name) = openhandle($xlsx_source) ? (readFromFileHandle => 'filehandle')
+                                                      : (read               => $xlsx_source);
+  my $result               = $zip->$meth($xlsx_source);
+  $result == AZ_OK  or die "cannot unzip from $source_name";
 
   return $zip;
 }
@@ -88,17 +90,10 @@ sub _sheet_for_table {
 #======================================================================
 
 
-sub base_year {
-  my ($self) = @_;
-  return $self->workbook_data->{base_year};
-}
-
-sub sheets {
-  my ($self) = @_;
-  return $self->workbook_data->{sheets};
-}
-
-
+# accessors to workbook data
+sub base_year    {shift->workbook_data->{base_year}   }
+sub sheets       {shift->workbook_data->{sheets}      }
+sub active_sheet {shift->workbook_data->{active_sheet}}
 
 
 sub Excel_builtin_date_formats {
